==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/vpnservicemulticast/multicast/rp/rpgroupmappings/RpGroupMappingKeys.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.vpnservicemulticast.multicast.rp.rpgroupmappings;

import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of rpGroupMapping.
 */
public class RpGroupMappingKeys implements KeyInfo<DefaultRpGroupMapping> {
    protected int id;
    /**
     * Returns the attribute id.
     *
     * @return id value of id
     */
    public int id() {
        return id;
    }

    /**
     * Sets the value to attribute id.
     *
     * @param id value of id
     */
    public void id(int id) {
        this.id = id;
    }


    @Override
    public int hashCode() {
        return Objects.hash(id);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof RpGroupMappingKeys) {
            RpGroupMappingKeys other = (RpGroupMappingKeys) obj;
            return
                Objects.equals(id, other.id);
        }
        return false;
    }
}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/vpnservicemulticast/multicast/rp/rpgroupmappings/RpGroupMappingKeys.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.vpnservicemulticast.multicast.rp.rpgroupmappings;

import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of rpGroupMapping.
 */
public class RpGroupMappingKeys implements KeyInfo<DefaultRpGroupMapping> {
    protected int id;
    /**
     * Returns the attribute id.
     *
     * @return id value of id
     */
    public int id() {
        return id;
    }

    /**
     * Sets the value to attribute id.
     *
     * @param id value of id
     */
    public void id(int id) {
        this.id = id;
    }


    @Override
    public int hashCode() {
        return Objects.hash(id);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof RpGroupMappingKeys) {
            RpGroupMappingKeys other = (RpGroupMappingKeys) obj;
            return
                Objects.deepEquals(id, other.id);
        }
        return false;
    }
}
